#ifndef _XewTextFont_h
#define _XewTextFont_h
/*
** Copyright 1992-1995 by Markku Savela and
**	Technical Research Centre of Finland
*/
#include <X11/Xew/Basic.h>

typedef struct XeFontListRec *XeFontList; /* Defined in TextFont.c */

_XFUNCPROTOBEGIN
XFontStruct *XeFindFont
	(
#if NeedFunctionPrototypes
	 Display *,	/* Display */
	 char *,	/* Pointer to constant character set string */
	 XeFontList,	/* FontList pointer or NULL */
	 int,		/* Weigth (_NORMAL, _FAINT, _BOLD) */
	 int,		/* Posture (TRUE = Italized) */
	 int		/* Requested pixel height of the font */
#endif
	 );

XeFontList XeMakeFontList
	(
#if NeedFunctionPrototypes
	 char *,	/* Font List Specification */
	 int		/* Length of the Font List specification */
#endif
	 );
_XFUNCPROTOEND

#endif

